@@ -1843,14 +1843,20 @@ class FileSystemBase(
         scope: aws_cdk.core.Construct,
         id: str,
         *,
+        account: typing.Optional[str] = None,
         physical_name: typing.Optional[str] = None,
+        region: typing.Optional[str] = None,
     ) -> None:
         """
         :param scope: -
         :param id: -
+        :param account: The AWS account ID this resource belongs to. Default: - the resource is in the same account as the stack it belongs to
         :param physical_name: The value passed in by users to the physical name prop of the resource. - ``undefined`` implies that a physical name will be allocated by CloudFormation during deployment. - a concrete value implies a specific physical name - ``PhysicalName.GENERATE_IF_NEEDED`` is a marker that indicates that a physical will only be generated by the CDK if it is needed for cross-environment references. Otherwise, it will be allocated by CloudFormation. Default: - The physical name will be allocated by CloudFormation at deployment time
+        :param region: The AWS region this resource belongs to. Default: - the resource is in the same region as the stack it belongs to
         """
-        props = aws_cdk.core.ResourceProps(physical_name=physical_name)
+        props = aws_cdk.core.ResourceProps(
+            account=account, physical_name=physical_name, region=region
+        )
 
         jsii.create(FileSystemBase, self, [scope, id, props])
 
